@@ -7,6 +7,12 @@
 #' are assigned. The similarity between aliases in each of the loanbook and ald
 #' datasets is scored using [stringdist::stringsim()].
 #'
+#' @section Package options:
+#' `r2dii.match.sector_classifications`: Allows you to use your own
+#' `sector_classififications` instead of the default. This feature is
+#' experimental and may be dropped and/or become a new argument to
+#' `match_name()`.
+#'
 #' @template alias-assign
 #' @template ignores-but-preserves-existing-groups
 #'
@@ -56,6 +62,7 @@
 #'
 #' @examples
 #' library(r2dii.data)
+#' library(tibble)
 #'
 #' # Small data for examples
 #' loanbook <- head(loanbook_demo, 50)
@@ -64,6 +71,36 @@
 #' match_name(loanbook, ald)
 #'
 #' match_name(loanbook, ald, min_score = 0.9)
+#'
+#' # Use your own `sector_classifications`
+#' your_classifications <- tibble(
+#'   sector = "power",
+#'   borderline = FALSE,
+#'   code = "3511",
+#'   code_system = "XYZ"
+#' )
+#'
+#' restore <- options(r2dii.match.sector_classifications = your_classifications)
+#'
+#' loanbook <- tibble(
+#'   sector_classification_system = "XYZ",
+#'   sector_classification_direct_loantaker = "3511",
+#'   id_ultimate_parent = "UP15",
+#'   name_ultimate_parent = "Alpine Knits India Pvt. Limited",
+#'   id_direct_loantaker = "C294",
+#'   name_direct_loantaker = "Yuamen Xinneng Thermal Power Co Ltd"
+#' )
+#'
+#' ald <- tibble(
+#'   name_company = "alpine knits india pvt. limited",
+#'   sector = "power",
+#'   alias_ald = "alpineknitsindiapvt ltd"
+#' )
+#'
+#' match_name(loanbook, ald)
+#'
+#' # Cleanup
+#' options(restore)
 match_name <- function(loanbook,
                        ald,
                        by_sector = TRUE,
@@ -98,6 +135,7 @@ match_name_impl <- function(loanbook,
   old_groups <- dplyr::groups(loanbook)
   loanbook <- ungroup(loanbook)
 
+  abort_if_duplicated_id_loan(loanbook)
   if (!allow_reserved_columns()) abort_reserved_column(loanbook)
   loanbook_rowid <- tibble::rowid_to_column(loanbook)
 
@@ -184,6 +222,28 @@ abort_reserved_column <- function(data) {
   invisible(data)
 }
 
+abort_if_duplicated_id_loan <- function(loanbook) {
+  column <- "id_loan"
+  if (!has_name(loanbook, column)) {
+    return(invisible(loanbook))
+  }
+
+  x <- loanbook[[column]]
+  dupl <- anyDuplicated(x)
+  if (dupl == 0L) {
+    return(invisible(loanbook))
+  }
+
+  first <- x[[dupl]]
+  msg <- glue("
+    All values of `{column}` in a `loanbook` must be unique (`{first}` is not).
+    Please ensure that every loan has a unique identifier.
+  ")
+  abort(msg, class = "duplicated_id_loan")
+
+  invisible(loanbook)
+}
+
 empty_loanbook_tibble <- function(loanbook, old_groups) {
   types <- loanbook %>%
     purrr::map_chr(typeof)
